/**
 * OW2 Util
 * Copyright (C) 2008-2012 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: IBean.java 6279 2012-08-23 09:42:00Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ejbjar.api.xml.struct;

import java.util.List;

import org.ow2.util.ee.metadata.common.api.xml.struct.IEnvironment;
import org.ow2.util.ee.metadata.common.api.xml.struct.IMethodDD;

/**
 * Common stuff of beans.
 * @author Florent Benoit
 */
public interface IBean extends IEnvironment {

    /**
     * Gets the ejb-name.
     * @return the ejb-name
     */
    String getEjbName();

    /**
     * Set the ejb-name.
     * @param ejbName ejbName
     */
    void setEjbName(final String ejbName);

    /**
     * Gets the ejb-class.
     * @return the ejb-class
     */
    String getEjbClass();

    /**
     * Set the ejb-class.
     * @param ejbClass ejb-class
     */
    void setEjbClass(final String ejbClass);

    /**
     * Gets the run-as role.
     * @return the run-as role
     */
    String getRunAsRole();

    /**
     * Set the run-as role.
     * @param runAsRole the run-as role
     */
    void setRunAsRole(final String runAsRole);

    /**
     * Gets the mapped name.
     * @return the mapped name
     */
    String getMappedName();

    /**
     * Set the mapped name.
     * @param mappedName the given mapped name.
     */
    void setMappedName(final String mappedName);

    /**
     * Gets the transaction-type.
     * @return the transaction-type
     */
    String getTransactionType();

    /**
     * Set the transaction-type.
     * @param transactionType transaction-type.
     */
    void setTransactionType(final String transactionType);

    /**
     * @return list of timers
     */
    List<ITimer> getTimers();
    
    /**
     * Adds a new timer.
     * @param timer the new timer
     */
    void addTimer(final ITimer timer);
    
    /**
     * @return the timeout method
     */
    IMethodDD getTimeoutMethod();


    /**
     * Set the timeout method.
     * @param timeoutMethod the given timeout.
     */
    void setTimeoutMethod(IMethodDD timeoutMethod);
}
